# Moderation

Types:

```python
from walledai.types import ModerationCreateResponse
```

Methods:

- <code title="post /guardrail">client.moderation.<a href="./src/walledai/resources/moderation.py">create</a>(\*\*<a href="src/walledai/types/moderation_create_params.py">params</a>) -> <a href="./src/walledai/types/moderation_create_response.py">object</a></code>
